@@ -3,7 +3,7 @@
 #############################################################################
 ## 
 ##   Logtalk uninstall script
-##   Last updated on January 10, 2023
+##   Last updated on October 12, 2023
 ## 
 ##   This file is part of Logtalk <https://logtalk.org/>  
 ##   SPDX-FileCopyrightText: 1998-2023 Paulo Moura <pmoura@logtalk.org>
@@ -85,7 +85,6 @@ rm -f logtalk_user_setup
 rm -f logtalk_version_select
 rm -f lvmlgt
 rm -f quintuslgt
-rm -f scryerlgt
 rm -f sicstuslgt
 rm -f swilgt
 rm -f taulgt
@@ -114,7 +113,6 @@ rm -f logtalk_user_setup.1.gz
 rm -f logtalk_version_select.1.gz
 rm -f lvmlgt.1.gz
 rm -f quintuslgt.1.gz
-rm -f scryerlgt.1.gz
 rm -f sicstuslgt.1.gz
 rm -f swilgt.1.gz
 rm -f taulgt.1.gz
@@ -122,8 +120,8 @@ rm -f tplgt.1.gz
 rm -f xsblgt.1.gz
 rm -f yaplgt.1.gz
 cd ../../info || exit 1
-rm -f LogtalkAPIs.info
-rm -f TheLogtalkHandbook.info
+rm -f LogtalkAPIs-$version.info
+rm -f TheLogtalkHandbook-$version.info
 
 echo "Logtalk $version system-level uninstall completed. For uninstalling user-level"
 echo "Logtalk files simply delete the LOGTALKUSER directories."
